=====
rotal
=====

.. image:: https://travis-ci.org/bwbaugh/rotal.svg?branch=master
    :target: https://travis-ci.org/bwbaugh/rotal
    :alt: Build Status

.. image:: https://coveralls.io/repos/bwbaugh/rotal/badge.svg
    :target: https://coveralls.io/r/bwbaugh/rotal
    :alt: Code Coverage Status

Get a running count of occurrences from a stream.
Intended to replace ``sort | uniq -c``
when the input is a stream.
